@@ -1,25 +1,13 @@
 #
 # File: OP.pm
 #
-# Copyright (c) 2005 TiVo Inc.
+# Copyright (c) 2009 TiVo Inc.
 #
 # All rights reserved. This program and the accompanying materials
 # are made available under the terms of the Common Public License v1.0
 # which accompanies this distribution, and is available at
 # http://opensource.org/licenses/cpl1.0.txt
 #
-package UNIVERSAL;
-
-#
-# Workaround for AutoLoader: Using Coro with OP makes AutoLoader throw
-# undef warnings in the context of a "require" statement when objects
-# without an explicit DESTROY method are culled.
-#
-# To work around this, OP adds an abstract DESTROY method to the the
-# UNIVERSAL package, which all objects in Perl inherit from. The DESTROY
-# method may be overridden as usual on a per-class basis.
-#
-sub DESTROY { }
 
 #
 # Add any cleanup/shutdown items to the DESTROY method below.
@@ -52,6 +40,21 @@ FILTER {
   s/^/$filterText/s;
 };
 
+do {
+  #
+  # Workaround for AutoLoader: Using Coro with OP makes AutoLoader throw
+  # undef warnings in the context of a "require" statement when objects
+  # without an explicit DESTROY method are culled.
+  #
+  # To work around this, OP adds an abstract DESTROY method to the the
+  # UNIVERSAL package, which all objects in Perl inherit from. The DESTROY
+  # method may be overridden as usual on a per-class basis.
+  #
+  no strict "refs";
+
+  *{"UNIVERSAL::DESTROY"} = sub { };
+};
+
 use Encode; # Load this legacy module before all else...
             # or suffer the undefined consequences!
 
@@ -135,13 +138,11 @@ __END__
 
 =head1 NAME
 
-OP - Objective Perl 5 (Overpowered)
+OP - Compact Perl 5 class prototyping with object persistence
 
 =head1 VERSION
 
-This documentation is for version B<0.20> of OP.
-
-  $Id: //depotit/tools/source/snitchd-0.20/lib/OP.pm#30 $
+This documentation is for version B<0.21> of OP.
 
 =head1 STATUS
 
@@ -394,49 +395,6 @@ it must pass the L<UNIVERSAL>C<::isa()> test). The Perl6::Subs equivalent
 pseudo-types are designed around Perl 5's native data types, and are
 suitable for testing non-objects.
 
-As an academic example, here are less-picky and more-picky subs:
-
-  #
-  # Less-picky, duck-typey sub:
-  #
-  sub doSomethingWithHash(Hash $hash) {
-    say $hash ? "I'm happy with $hash" : "I got nothin'";
-  }
-
-  #
-  # Pickier sub:
-  #
-  sub pickyHashSub(OP::Hash $hash) {
-    doSomethingWithHash($hash);
-  }
-
-Here is code to test the less-picky version:
-
-  #
-  # This says "I'm happy with OP::Hash=HASH(0xDEADBEEF)"
-  #
-  doSomethingWithHash(OP::Hash->new());
-
-  #
-  # This says "I'm happy with HASH(0xDEADBEEF)"
-  #
-  doSomethingWithHash({ });
-
-And code to test its pickier counterpart:
-
-  #
-  # This says "I'm happy with OP::Hash=HASH(0xDEADBEEF)":
-  #
-  pickyHashSub(OP::Hash->new());
-
-  #
-  # But this will throw an exception like:
-  #
-  # - Unhandled OP::InvalidArgument Exception:
-  #   Parameter $hash is not an OP::Hash in call to main::pickyHashSub ...
-  #
-  pickyHashSub({ });
-
 Note that constructors and setter methods accept both native Perl 5 data
 types and their OP object class equivalents. The setters will
 automatically handle any necessary conversion, or throw an exception if
