@@ -12,12 +12,10 @@
 
 =head1 NAME
 
-OP::Code
+OP::Code - Object class for code blocks
 
 =head1 DESCRIPTION
 
-Object class for code blocks.
-
 Extends L<OP::Ref>
 
 =head1 SYNOPSIS
