@@ -30,7 +30,7 @@ method assert(OP::Class $class: *@rules) {
       my $self = shift;
 
       if ( !ref($self) || !UNIVERSAL::isa($self,"Email::Address") ) {
-        $self = Email::Address->parse($self);
+        $self = $class->new($self);
       }
 
       Data::Validate::Email::is_email($self->address)
@@ -70,7 +70,7 @@ __END__
 
 =head1 NAME
 
-OP::EmailAddr
+OP::EmailAddr - Overloaded RFC 2822 email address object
 
 =head1 VERSION
 
@@ -103,8 +103,6 @@ OP::EmailAddr
 
 =head1 DESCRIPTION
 
-Overloaded RFC 2822 email address object.
-
 Extends L<Email::Address>, L<OP::Array>. Uses L<Data::Validate::Email>
 to verify input.
 
