@@ -52,7 +52,7 @@ __END__
 
 =head1 NAME
 
-OP::URI
+OP::URI - Overloaded URI object class
 
 =head1 VERSION
 
@@ -66,8 +66,6 @@ OP::URI
 
 =head1 DESCRIPTION
 
-URI object.
-
 Extends L<URI>, L<OP::Str>. Uses L<Data::Validate::URI> to verify input.
 
 =head1 PUBLIC CLASS METHODS
